@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2018, 2019 Esteban J. G. Gabancho.
+# Copyright (C) 2020 CESNET
 #
 # oarepo-s3 is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
@@ -110,11 +110,11 @@ class MockedS3Client(S3Client):
                 "finish_url": ""
                 }
 
-    def complete_multipart_upload(self, bucket, object_name, parts, upload_id):
+    def complete_multipart_upload(self, bucket, key, parts, upload_id):
         """Faked complete of a multipart upload to AWS S3."""
         return {'status': 'completed', 'ETag': 'etag:test'}
 
-    def abort_multipart_upload(self, bucket, object_name, upload_id):
+    def abort_multipart_upload(self, bucket, key, upload_id):
         """Faked cancel of an in-progress multipart upload to AWS S3."""
         return {'status': 'aborted'}
 
